@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -371,10 +371,10 @@ class MainWgt(QtGui.QMainWindow):
             if hasattr (self, 'con_lost_lbl'):
                 self.con_lost_lbl.hide()
                 self.con_lost_lbl.close()
-            self.con_lost_lbl = ConnectLostLabel \
-                            (_("The server was restarted.") + '\n' + \
-                            _('Reconnecting to the server.'),
-                            self)
+            self.con_lost_lbl = ConnectLostLabel(
+                _("The server was restarted") + '.\n' + \
+                _('Reconnecting to the server') + '...',
+                self)
             self.topmenu.Processes.setDisabled(True)
             self.topmenu.Session.setDisabled(True)
             self.topmenu.Back.setDisabled(True)
